@@ -87,10 +87,11 @@ class ModelsTestCase(unittest.TestCase):
         self.assertEquals(p2.source.uuid, p.uuid)
 
     def mk_category(self, title, subtitle='subtitle',
-                    language=None, source=None):
+                    language=None, source=None, featured=False):
         models = self.get_repo_models()
         category = models.GitCategoryModel(
-            title=title, subtitle=subtitle, language=language, source=source)
+            title=title, subtitle=subtitle, language=language, source=source,
+            featured_in_navbar=featured)
         category.save(True)
         return category
 
@@ -115,13 +116,15 @@ class ModelsTestCase(unittest.TestCase):
 
     def test_category_to_dict(self):
         category1 = self.mk_category('category1')
-        category2 = self.mk_category('category2', source=category1)
+        category2 = self.mk_category(
+            'category2', source=category1, featured=True)
         self.assertEquals(category2.to_dict(), {
             'uuid': category2.uuid,
             'title': u'category2',
             'subtitle': 'subtitle',
             'slug': u'category2',
             'language': '',
+            'featured_in_navbar': True,
             'source': category1.to_dict(),
         })
 
@@ -148,4 +151,5 @@ class ModelsTestCase(unittest.TestCase):
             'source': page1.to_dict(),
             'featured_in_category': True,
             'featured': True,
+            'language': 'eng-US',
         })
